@@ -21,8 +21,7 @@
 #ifndef GOG_GRID_H
 #define GOG_GRID_H
 
-#include <goffice/graph/goffice-graph.h>
-#include <glib-object.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
