@@ -45,8 +45,8 @@ static GSList *refd_plugins;
 
 static GType gog_plot_engine_service_get_type (void);
 
-typedef PluginServiceGObjectLoader	GogPlotEngineService;
-typedef PluginServiceGObjectLoaderClass GogPlotEngineServiceClass;
+typedef GOPluginServiceGObjectLoader	GogPlotEngineService;
+typedef GOPluginServiceGObjectLoaderClass GogPlotEngineServiceClass;
 
 static GHashTable *pending_engines = NULL;
 
@@ -57,7 +57,7 @@ gog_plot_engine_service_get_description (GOPluginService *service)
 }
 
 static void
-gog_plot_engine_service_class_init (PluginServiceGObjectLoaderClass *gobj_loader_class)
+gog_plot_engine_service_class_init (GOPluginServiceGObjectLoaderClass *gobj_loader_class)
 {
 	GOPluginServiceClass *ps_class = GPS_CLASS (gobj_loader_class);
 
@@ -77,7 +77,7 @@ gog_plot_new_by_name (char const *id)
 	GType type = g_type_from_name (id);
 
 	if (type == 0) {
-		ErrorInfo *err = NULL;
+		GOErrorInfo *err = NULL;
 		GOPluginService *service =
 			pending_engines
 			? g_hash_table_lookup (pending_engines, id)
@@ -89,12 +89,12 @@ gog_plot_new_by_name (char const *id)
 
 		g_return_val_if_fail (!service->is_loaded, NULL);
 
-		plugin_service_load (service, &err);
+		go_plugin_service_load (service, &err);
 		type = g_type_from_name (id);
 
 		if (err != NULL) {
-			error_info_print (err);
-			error_info_free	(err);
+			go_error_info_print (err);
+			go_error_info_free	(err);
 		}
 
 		g_return_val_if_fail (type != 0, NULL);
@@ -102,7 +102,7 @@ gog_plot_new_by_name (char const *id)
 		/*
 		 * The plugin defined a gtype so it must not be unloaded.
 		 */
-		plugin = plugin_service_get_plugin (service);
+		plugin = go_plugin_service_get_plugin (service);
 		refd_plugins = g_slist_prepend (refd_plugins, plugin);
 		g_object_ref (plugin);
 		go_plugin_use_ref (plugin);
@@ -121,13 +121,13 @@ gog_plot_new_by_name (char const *id)
 GType gog_plot_type_service_get_type (void);
 
 typedef struct {
-	PluginServiceSimple	base;
+	GOPluginServiceSimple	base;
 
 	GSList	*families, *types, *paths;
 } GogPlotTypeService;
 
 typedef struct{
-	PluginServiceSimpleClass	base;
+	GOPluginServiceSimpleClass	base;
 } GogPlotTypeServiceClass;
 
 static GHashTable *pending_plot_type_files = NULL;
@@ -154,7 +154,7 @@ cb_pending_plot_types_load (char const *path,
 		if (!xmlIsBlankNode (ptr) && ptr->name && !strcmp (ptr->name, "Family")) {
 			name	    = xmlGetProp (ptr, "_name");
 			image_file  = xmlGetProp (ptr, "sample_image_file");
-			if (!xml_node_get_int (ptr, "priority", &priority))
+			if (!go_xml_node_get_int (ptr, "priority", &priority))
 				priority = 0;
 			axis_set_str = xmlGetProp (ptr, "axis_set");
 			axis_set = gog_axis_set_from_str (axis_set_str);
@@ -183,8 +183,8 @@ cb_pending_plot_types_load (char const *path,
 			image_file  = xmlGetProp (ptr, "sample_image_file");
 			description = xmlGetProp (ptr, "_description");
 			engine	    = xmlGetProp (ptr, "engine");
-			if (xml_node_get_int (ptr, "col", &col) &&
-			    xml_node_get_int (ptr, "row", &row)) {
+			if (go_xml_node_get_int (ptr, "col", &col) &&
+			    go_xml_node_get_int (ptr, "row", &row)) {
 				type = gog_plot_type_register (family, col, row,
 					name, image_file, description, engine);
 				if (type != NULL) {
@@ -230,7 +230,7 @@ pending_plot_types_load (void)
 }
 
 static void
-gog_plot_type_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+gog_plot_type_service_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	char    *path;
 	xmlNode *ptr;
@@ -241,7 +241,7 @@ gog_plot_type_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorIn
 		    NULL != (path = xmlNodeGetContent (ptr))) {
 			if (!g_path_is_absolute (path)) {
 				char const *dir = go_plugin_get_dir_name (
-					plugin_service_get_plugin (service));
+					go_plugin_service_get_plugin (service));
 				char *tmp = g_build_filename (dir, path, NULL);
 				g_free (path);
 				path = tmp;
@@ -252,7 +252,7 @@ gog_plot_type_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorIn
 }
 
 static void
-gog_plot_type_service_activate (GOPluginService *service, ErrorInfo **ret_error)
+gog_plot_type_service_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	GSList *l = GOG_PLOT_TYPE_SERVICE (service)->paths;
 	if (l && pending_plot_type_files == NULL)
@@ -267,7 +267,7 @@ gog_plot_type_service_activate (GOPluginService *service, ErrorInfo **ret_error)
 }
 
 static void
-gog_plot_type_service_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+gog_plot_type_service_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	GogPlotTypeService *plot_service = GOG_PLOT_TYPE_SERVICE (service);
 	GSList *l = plot_service->families;
@@ -362,11 +362,11 @@ GSF_CLASS (GogPlotTypeService, gog_plot_type_service,
 
 GType gog_theme_service_get_type (void);
 
-typedef PluginServiceSimple GogThemeService;
-typedef PluginServiceSimpleClass GogThemeServiceClass;
+typedef GOPluginServiceSimple GogThemeService;
+typedef GOPluginServiceSimpleClass GogThemeServiceClass;
 
 static void
-gog_theme_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+gog_theme_service_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	GogTheme *theme;
 	xmlNode *ptr;
@@ -377,12 +377,12 @@ gog_theme_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo *
 		    NULL != (path = xmlNodeGetContent (ptr))) {
 			if (!g_path_is_absolute (path)) {
 				char const *dir = go_plugin_get_dir_name (
-					plugin_service_get_plugin (service));
+					go_plugin_service_get_plugin (service));
 				char *tmp = g_build_filename (dir, path, NULL);
 				g_free (path);
 				path = tmp;
 			}
-			theme = gog_theme_new_from_file (plugin_service_get_description (service),
+			theme = gog_theme_new_from_file (go_plugin_service_get_description (service),
 							 path);
 			gog_theme_registry_add (theme, FALSE);	
 		}
@@ -414,8 +414,8 @@ GSF_CLASS (GogThemeService, gog_theme_service,
 
 static GType gog_trend_line_engine_service_get_type (void);
 
-typedef PluginServiceGObjectLoader	GogTrendLineEngineService;
-typedef PluginServiceGObjectLoaderClass GogTrendLineEngineServiceClass;
+typedef GOPluginServiceGObjectLoader	GogTrendLineEngineService;
+typedef GOPluginServiceGObjectLoaderClass GogTrendLineEngineServiceClass;
 
 static GHashTable *pending_trend_lines_engines = NULL;
 
@@ -426,7 +426,7 @@ gog_trend_line_engine_service_get_description (GOPluginService *service)
 }
 
 static void
-gog_trend_line_engine_service_class_init (PluginServiceGObjectLoaderClass *gobj_loader_class)
+gog_trend_line_engine_service_class_init (GOPluginServiceGObjectLoaderClass *gobj_loader_class)
 {
 	GOPluginServiceClass *ps_class = GPS_CLASS (gobj_loader_class);
 
@@ -446,7 +446,7 @@ gog_trend_line_new_by_name (char const *id)
 	GType type = g_type_from_name (id);
 
 	if (type == 0) {
-		ErrorInfo *err = NULL;
+		GOErrorInfo *err = NULL;
 		GOPluginService *service =
 			pending_trend_lines_engines
 			? g_hash_table_lookup (pending_trend_lines_engines, id)
@@ -458,12 +458,12 @@ gog_trend_line_new_by_name (char const *id)
 
 		g_return_val_if_fail (!service->is_loaded, NULL);
 
-		plugin_service_load (service, &err);
+		go_plugin_service_load (service, &err);
 		type = g_type_from_name (id);
 
 		if (err != NULL) {
-			error_info_print (err);
-			error_info_free	(err);
+			go_error_info_print (err);
+			go_error_info_free	(err);
 		}
 
 		g_return_val_if_fail (type != 0, NULL);
@@ -471,7 +471,7 @@ gog_trend_line_new_by_name (char const *id)
 		/*
 		 * The plugin defined a gtype so it must not be unloaded.
 		 */
-		plugin = plugin_service_get_plugin (service);
+		plugin = go_plugin_service_get_plugin (service);
 		refd_plugins = g_slist_prepend (refd_plugins, plugin);
 		g_object_ref (plugin);
 		go_plugin_use_ref (plugin);
@@ -489,11 +489,11 @@ gog_trend_line_new_by_name (char const *id)
 GType gog_trend_line_service_get_type (void);
 
 typedef struct {
-	PluginServiceSimple	base;
+	GOPluginServiceSimple	base;
 
 	GSList	*types, *paths;
 } GogTrendLineService;
-typedef PluginServiceSimpleClass GogTrendLineServiceClass;
+typedef GOPluginServiceSimpleClass GogTrendLineServiceClass;
 
 static GHashTable *pending_trend_line_type_files = NULL;
 static GHashTable *trend_line_types = NULL;
@@ -551,7 +551,7 @@ pending_trend_line_types_load (void)
 }
 
 static void
-gog_trend_line_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorInfo **ret_error)
+gog_trend_line_service_read_xml (GOPluginService *service, xmlNode *tree, GOErrorInfo **ret_error)
 {
 	char    *path;
 	xmlNode *ptr;
@@ -562,7 +562,7 @@ gog_trend_line_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorI
 		    NULL != (path = xmlNodeGetContent (ptr))) {
 			if (!g_path_is_absolute (path)) {
 				char const *dir = go_plugin_get_dir_name (
-					plugin_service_get_plugin (service));
+					go_plugin_service_get_plugin (service));
 				char *tmp = g_build_filename (dir, path, NULL);
 				g_free (path);
 				path = tmp;
@@ -573,7 +573,7 @@ gog_trend_line_service_read_xml (GOPluginService *service, xmlNode *tree, ErrorI
 }
 
 static void
-gog_trend_line_service_activate (GOPluginService *service, ErrorInfo **ret_error)
+gog_trend_line_service_activate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	GSList *l = GOG_TREND_LINE_SERVICE (service)->paths;
 	if (l && pending_trend_line_type_files == NULL)
@@ -588,7 +588,7 @@ gog_trend_line_service_activate (GOPluginService *service, ErrorInfo **ret_error
 }
 
 static void
-gog_trend_line_service_deactivate (GOPluginService *service, ErrorInfo **ret_error)
+gog_trend_line_service_deactivate (GOPluginService *service, GOErrorInfo **ret_error)
 {
 	GogTrendLineService *line_service = GOG_TREND_LINE_SERVICE (service);
 	GSList *l = line_service->types;
@@ -661,17 +661,17 @@ GSF_CLASS (GogTrendLineService, gog_trend_line_service,
 /***************************************************************************/
 
 void
-gog_plugin_services_init (void)
+_gog_plugin_services_init (void)
 {
-	plugin_service_define ("plot_engine", &gog_plot_engine_service_get_type);
-	plugin_service_define ("plot_type",   &gog_plot_type_service_get_type);
-	plugin_service_define ("chart_theme",  &gog_theme_service_get_type);
-	plugin_service_define ("trendline_engine", &gog_trend_line_engine_service_get_type);
-	plugin_service_define ("trendline_type", &gog_trend_line_service_get_type);
+	go_plugin_service_define ("plot_engine", &gog_plot_engine_service_get_type);
+	go_plugin_service_define ("plot_type",   &gog_plot_type_service_get_type);
+	go_plugin_service_define ("chart_theme",  &gog_theme_service_get_type);
+	go_plugin_service_define ("trendline_engine", &gog_trend_line_engine_service_get_type);
+	go_plugin_service_define ("trendline_type", &gog_trend_line_service_get_type);
 }
 
 void
-gog_plugin_services_shutdown (void)
+_gog_plugin_services_shutdown (void)
 {
 	g_slist_foreach (refd_plugins, (GFunc)go_plugin_use_unref, NULL);
 	g_slist_foreach (refd_plugins, (GFunc)g_object_unref, NULL);
