@@ -20,14 +20,7 @@
  */
 
 #include <goffice/goffice-config.h>
-
-#include <goffice/graph/gog-view.h>
-#include <goffice/graph/gog-object.h>
-#include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-styled-object.h>
-#include <goffice/graph/gog-style.h>
-
-#include <goffice/utils/go-color.h>
+#include <goffice/goffice.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
@@ -48,7 +41,7 @@ static void
 gog_tool_select_object_render (GogView *view)
 {
 	GogViewAllocation rect = view->allocation;
-	GogStyle *style = gog_styled_object_get_style (GOG_STYLED_OBJECT (view->model));
+	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (view->model));
 	double line_width = gog_renderer_line_size (view->renderer, style->line.width);
 
 	rect.x -= line_width / 2.0;
@@ -201,7 +194,7 @@ gog_tool_action_new (GogView *view, GogTool *tool, double x, double y)
 {
 	GogToolAction *action;
 
-	g_return_val_if_fail (IS_GOG_VIEW (view), NULL);
+	g_return_val_if_fail (GOG_IS_VIEW (view), NULL);
 	g_return_val_if_fail (tool != NULL, NULL);
 
 	action = g_new0 (GogToolAction, 1);
@@ -590,13 +583,13 @@ gog_view_class_init (GogViewClass *view_klass)
 		g_param_spec_object ("parent", 
 			_("Parent"),
 			_("the GogView parent"),
-			GOG_VIEW_TYPE,
+			GOG_TYPE_VIEW,
 			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 	g_object_class_install_property (gobject_klass, GOG_VIEW_PROP_MODEL,
 		g_param_spec_object ("model", 
 			_("Model"),
 			_("The GogObject this view displays"),
-			GOG_OBJECT_TYPE,
+			GOG_TYPE_OBJECT,
 			GSF_PARAM_STATIC | G_PARAM_WRITABLE));
 }
 
@@ -631,7 +624,7 @@ gog_view_get_model (GogView const *view)
 void
 gog_view_queue_redraw (GogView *view)
 {
-	g_return_if_fail (IS_GOG_VIEW (view));
+	g_return_if_fail (GOG_IS_VIEW (view));
 	g_return_if_fail (view->renderer != NULL);
 
 	gog_renderer_request_update (view->renderer);
@@ -648,7 +641,7 @@ gog_view_queue_redraw (GogView *view)
 void
 gog_view_queue_resize (GogView *view)
 {
-	g_return_if_fail (IS_GOG_VIEW (view));
+	g_return_if_fail (GOG_IS_VIEW (view));
 	g_return_if_fail (view->renderer != NULL);
 
 	gog_renderer_request_update (view->renderer);
@@ -735,10 +728,16 @@ gog_view_size_allocate (GogView *view, GogViewAllocation const *allocation)
 	view->allocation_valid = view->child_allocations_valid = TRUE;
 }
 
+/**
+ * gog_view_update_sizes:
+ * @view : #GogView
+ *
+ * Returns: %TRUE if a redraw is necessary.
+ **/
 gboolean
 gog_view_update_sizes (GogView *view)
 {
-	g_return_val_if_fail (IS_GOG_VIEW (view), TRUE);
+	g_return_val_if_fail (GOG_IS_VIEW (view), TRUE);
 	g_return_val_if_fail (!view->being_updated, TRUE);
 
 	if (!view->allocation_valid)
@@ -765,7 +764,8 @@ gog_view_render	(GogView *view, GogViewAllocation const *bbox)
 	g_return_if_fail (view->renderer != NULL);
 
 	/* In particular this is true for NaNs.  */
-	if (!(view->allocation.w >= 0 && view->allocation.h >= 0))
+	if (view->model->invisible ||
+	    !(view->allocation.w >= 0 && view->allocation.h >= 0))
 		return;
 
 	if (klass->clip) {
@@ -857,8 +857,8 @@ gog_view_find_child_view  (GogView const *container, GogObject const *target_mod
 	GogObject const *obj, *old_target;
 	GSList *ptr;
 
-	g_return_val_if_fail (IS_GOG_VIEW (container), NULL);
-	g_return_val_if_fail (IS_GOG_OBJECT (target_model), NULL);
+	g_return_val_if_fail (GOG_IS_VIEW (container), NULL);
+	g_return_val_if_fail (GOG_IS_OBJECT (target_model), NULL);
 
 	/* @container is a view for @target_models parent */
 	obj = target_model;
@@ -900,7 +900,7 @@ gog_view_render_toolkit (GogView *view)
 	GogTool *tool;
 	GSList const *ptr;
 	
-	g_return_if_fail (IS_GOG_VIEW (view));
+	g_return_if_fail (GOG_IS_VIEW (view));
 
 	for (ptr = gog_view_get_toolkit (view); ptr != NULL; ptr = ptr->next) {
 		tool = ptr->data;
@@ -919,7 +919,7 @@ gog_view_render_toolkit (GogView *view)
 GSList const *
 gog_view_get_toolkit (GogView *view)
 {
-	g_return_val_if_fail (IS_GOG_VIEW (view), NULL);
+	g_return_val_if_fail (GOG_IS_VIEW (view), NULL);
 
 	if  (view->toolkit == NULL) {
 		GogViewClass *klass = GOG_VIEW_GET_CLASS (view);
@@ -933,8 +933,11 @@ gog_view_get_toolkit (GogView *view)
 /**
  * gog_view_get_tool_at_point:
  * @view : #GogView
+ * @x : in coords
+ * @y : in coords
+ * @gobj : non-%NULL storage.
  * 
- * Find tool under cursor for a given view.
+ * Returns: tool under cursor for a given view, or %NULL
  **/
 GogTool *
 gog_view_get_tool_at_point (GogView *view, double x, double y, GogObject **gobj)
@@ -979,7 +982,7 @@ gog_view_get_view_at_point (GogView *view, double x, double y, GogObject **obj,
 	GSList const *ptr;
 	GSList *list;
 	
-	g_return_val_if_fail (IS_GOG_VIEW (view), NULL);
+	g_return_val_if_fail (GOG_IS_VIEW (view), NULL);
 
 	/* walk the list in reverse */
 	list = g_slist_reverse (g_slist_copy (view->children));
