@@ -23,20 +23,6 @@
 #include "go-combo-box.h"
 #include "goffice-gtk.h"
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkcontainer.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkscrolledwindow.h>
-
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 #include <stdio.h>
@@ -68,11 +54,11 @@ enum {
 	KEY_COL
 };
 
-#define GO_COMBO_STACK_TYPE	(go_combo_stack_get_type ())
-#define GO_COMBO_STACK(o)	G_TYPE_CHECK_INSTANCE_CAST (o, GO_COMBO_STACK_TYPE, GOComboStack)
-#define IS_GO_COMBO_STACK(o)	G_TYPE_CHECK_INSTANCE_TYPE (o, GO_COMBO_STACK_TYPE)
+#define GO_TYPE_COMBO_STACK	(go_combo_stack_get_type ())
+#define GO_COMBO_STACK(o)	G_TYPE_CHECK_INSTANCE_CAST (o, GO_TYPE_COMBO_STACK, GOComboStack)
+#define GO_IS_COMBO_STACK(o)	G_TYPE_CHECK_INSTANCE_TYPE (o, GO_TYPE_COMBO_STACK)
 
-static GtkType go_combo_stack_get_type   (void);
+static GType go_combo_stack_get_type   (void);
 static guint go_combo_stack_signals [LAST_SIGNAL] = { 0, };
 
 static void
@@ -228,7 +214,7 @@ go_combo_stack_class_init (GObjectClass *klass)
 
 GSF_CLASS (GOComboStack, go_combo_stack,
 	   go_combo_stack_class_init, go_combo_stack_init,
-	   GO_COMBO_BOX_TYPE)
+	   GO_TYPE_COMBO_BOX)
 
 /**************************************************************************/
 
@@ -238,9 +224,9 @@ typedef struct {
 } GOToolComboStack;
 typedef GtkToolItemClass GOToolComboStackClass;
 
-#define GO_TOOL_COMBO_STACK_TYPE	(go_tool_combo_stack_get_type ())
-#define GO_TOOL_COMBO_STACK(o)		(G_TYPE_CHECK_INSTANCE_CAST (o, GO_TOOL_COMBO_STACK_TYPE, GOToolComboStack))
-#define IS_GO_TOOL_COMBO_STACK(o)	(G_TYPE_CHECK_INSTANCE_TYPE (o, GO_TOOL_COMBO_STACK_TYPE))
+#define GO_TYPE_TOOL_COMBO_STACK	(go_tool_combo_stack_get_type ())
+#define GO_TOOL_COMBO_STACK(o)		(G_TYPE_CHECK_INSTANCE_CAST (o, GO_TYPE_TOOL_COMBO_STACK, GOToolComboStack))
+#define GO_IS_TOOL_COMBO_STACK(o)	(G_TYPE_CHECK_INSTANCE_TYPE (o, GO_TYPE_TOOL_COMBO_STACK))
 
 static GType go_tool_combo_stack_get_type (void);
 
@@ -304,13 +290,13 @@ go_action_combo_stack_create_tool_item (GtkAction *a)
 	GOActionComboStack *saction = (GOActionComboStack *)a;
 	GtkWidget *image;
 	GtkTreeView *tree_view;
-	GOToolComboStack *tool = g_object_new (GO_TOOL_COMBO_STACK_TYPE, NULL);
+	GOToolComboStack *tool = g_object_new (GO_TYPE_TOOL_COMBO_STACK, NULL);
 	char *stock_id;
 	gboolean is_sensitive = gtk_tree_model_iter_n_children (saction->model, NULL) > 0;
 	GtkIconSize size;
 	GtkSettings *settings;
 
-	tool->combo = g_object_new (GO_COMBO_STACK_TYPE, NULL);
+	tool->combo = g_object_new (GO_TYPE_COMBO_STACK, NULL);
 	tree_view = GTK_TREE_VIEW (tool->combo->list);
 	gtk_tree_view_set_model (tree_view, saction->model);
 	gtk_tree_view_set_headers_visible (tree_view, FALSE);
@@ -409,10 +395,10 @@ check_sensitivity (GOActionComboStack *saction, unsigned old_count)
  * @key : a key value to id the pushe item
  **/
 void
-go_action_combo_stack_push (GOActionComboStack *a,
+go_action_combo_stack_push (GOActionComboStack *act,
 			    char const *label, gpointer key)
 {
-	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (a);
+	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (act);
 	GtkTreeIter iter;
 	unsigned old_count = gtk_tree_model_iter_n_children (saction->model, NULL);
 
@@ -429,15 +415,15 @@ go_action_combo_stack_push (GOActionComboStack *a,
 /**
  * go_action_combo_stack_pop :
  * @act : #GOActionComboStack
- * @n :
+ * @n : count
  *
  * Shorten list @act by removing @n off the top (or fewer if the list is
  * shorter)
  **/
 void
-go_action_combo_stack_pop (GOActionComboStack *a, unsigned n)
+go_action_combo_stack_pop (GOActionComboStack *act, unsigned n)
 {
-	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (a);
+	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (act);
 	GtkTreeIter iter;
 	unsigned old_count = gtk_tree_model_iter_n_children (saction->model, NULL);
 
@@ -453,20 +439,22 @@ go_action_combo_stack_pop (GOActionComboStack *a, unsigned n)
 /**
  * go_action_combo_stack_truncate :
  * @act : #GOActionComboStack
- * @n : 
+ * @n : maximum length
  *
  * Ensure that list @act is no longer than @n, dropping any extra off the
  * bottom.
  **/
 void
-go_action_combo_stack_truncate (GOActionComboStack *a, unsigned n)
+go_action_combo_stack_truncate (GOActionComboStack *act, unsigned n)
 {
-	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (a);
+	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (act);
 	GtkTreeIter iter;
-	unsigned old_count = gtk_tree_model_iter_n_children (saction->model, NULL);
+	unsigned old_count;
 
 	g_return_if_fail (saction != NULL);
 
+	old_count = gtk_tree_model_iter_n_children (saction->model, NULL);
+
 	if (gtk_tree_model_iter_nth_child (saction->model, &iter, NULL, n))
 		while (gtk_list_store_remove (GTK_LIST_STORE (saction->model), &iter))
 			;
