@@ -28,7 +28,8 @@
 #include <goffice/graph/gog-object.h>
 #include <goffice/graph/gog-plot.h>
 #include <goffice/graph/gog-series.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 #include <goffice/gtk/go-graph-widget.h>
 
 static void
@@ -47,7 +48,7 @@ main (int argc, char *argv[])
 	GogLabel *label;
 	GogPlot *pie;
 	GogSeries *series;
-	GogStyle *style;
+	GOStyle *style;
 	GOData *data;
 	GError *error;
 	PangoFontDescription *desc;
@@ -59,7 +60,7 @@ main (int argc, char *argv[])
 	/* Initialize libgoffice */
 	libgoffice_init ();
 	/* Initialize plugins manager */
-	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_resize (GTK_WINDOW (window), 300, 340);
@@ -75,19 +76,19 @@ main (int argc, char *argv[])
 	gtk_box_pack_end (GTK_BOX (box), w, FALSE, FALSE, 2);
 
 	/* Create a graph widget and add it to the GtkVBox */
-	w = go_graph_widget_new ();
+	w = go_graph_widget_new (NULL);
 	gtk_box_pack_end (GTK_BOX (box), w, TRUE, TRUE, 0);
 	/* Get the embedded graph */
 	graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (w));
 	/* Add a title */
-	label = (GogLabel *) g_object_new (GOG_LABEL_TYPE, NULL);
+	label = (GogLabel *) g_object_new (GOG_TYPE_LABEL, NULL);
 	data = go_data_scalar_str_new (title, FALSE);
 	gog_dataset_set_dim (GOG_DATASET (label), 0, data, NULL);
 	gog_object_add_by_name (GOG_OBJECT (graph), "Title", GOG_OBJECT (label));
 	/* Change the title font */
-	style = gog_styled_object_get_style (GOG_STYLED_OBJECT (label));
+	style = go_styled_object_get_style (GO_STYLED_OBJECT (label));
 	desc = pango_font_description_from_string ("Sans bold 16");
-	gog_style_set_font_desc (style, desc);
+	go_style_set_font_desc (style, desc);
 	/* Get the chart created by the widget initialization */
 	chart = go_graph_widget_get_chart (GO_GRAPH_WIDGET (w));
 	/* Create a pie plot and add it to the chart */
